#!/usr/bin/perl

use strict;
use warnings;

print <<'EOF';
This package was originally debianized by Takuo KITAME <kitame@debian.org> on
Fri, 17 Jan 2003 14:57:28 +0900.
Andreas Henriksson <andreas@fatal.se> later reused the gnome-icon-theme
packaging for the new adwaita-icon-theme package name.

It was downloaded from <https://download.gnome.org/sources/adwaita-icon-theme/>

Files: *
Copyright:
 © 2002-2014:
 .
  Full Color Icons
  ================
 .
  Ulisse Perusin <uli.peru@gmail.com>
  Riccardo Buzzotta <raozuzu@yahoo.it>
  Josef Vybíral <cornelius@vybiral.info>
  Hylke Bons <h.bons@gmail.com>
  Ricardo González <rick@jinlabs.com>
  Lapo Calamandrei <calamandrei@gmail.com>
  Rodney Dawes <dobey@novell.com>
  Luca Ferretti <elle.uca@libero.it>
  Tuomas Kuosmanen <tigert@gimp.org>
  Andreas Nilsson <nisses.mail@home.se>
  Jakub Steiner <jimmac@novell.com>
 .
  Some external 3D Assets used:
  Geraldo Cockerhan - http://www.blendswap.com/blends/view/40495 CCBYSA
 .
  Symbolic Icons
  ==============
 .
  Metaphors
  ---------
  Claire Alexander <claire.alexander@intel.com>
  Hylke Bons <hylke.bons@intel.com>
  Darren Wilson <darren.wilson@intel.com>
 .
  Artwork
  -------
  Jakub Steiner <jimmac@novell.com>
  Lapo Calamandrei <calamandrei@gmail.com>
  Hylke Bons <hylke.bons@intel.com>
 .
License: CC-BY-SA-3.0 or LGPL-3
 This work is licenced under the terms of either the GNU LGPL v3 or
 Creative Commons Attribution-Share Alike 3.0 United States License.
 .
 To view a copy of the CC-BY-SA licence, visit
 https://creativecommons.org/licenses/by-sa/3.0/ or send a letter to Creative
 Commons, 171 Second Street, Suite 300, San Francisco, California 94105, USA.
 .
 When attributing the artwork, using "GNOME Project" is enough.
 Please link to https://www.gnome.org where available.
Comment:
 See below for the full text of the CC-BY-SA-3.0.
 .
 On Debian GNU/Linux systems, the complete text of the GNU Lesser General
 Public License can be found in `/usr/share/common-licenses/LGPL-3'.

Files:
 po/*
Copyright:
 © 2004 Abdulaziz Al-Arfaj
 © 2003-2006 Abel Cheung
 © 2004-2005 Adam Weinberger
 © 2009 Adi Roiban
 © 2004 Aleksandar Urošević
 © 2003-2010 Ales Nyakhaychyk
 © 2004-2008 Alexander Shopov
 © 2014 Alexandre Franke
 © 2003 Allan Sims
 © 2004-2014 Amanpreet Singh Alam
 © 2009 Amitakhya Phukan
 © 2014 Anders Jonsson
 © 2014 Andika Triwidada
 © 2002-2004 Andras Timar
 © 2006 Ani Peter
 © 2004-2007 Ankit Patel
 © 2003 Arafat Medini
 © 2004-2008 Arangel Angov
 © 2002 Artis Trops
 © 2003-2005 Artur Flinta
 © 2005 Augustin KIBERWA
 © 2008 Automatski Prijevod
 © 2007-2014 Aviary.pl
 © 2014 Balázs Meskó
 © (unspecified) Branko Ivanović
 © 2005-2011 Canonical Ltd.
 © 2005 Carole Karema
 © 2014 Changwoo Ryu
 © 2006-2014 Christian Kintner
 © 2002-2004 Christian Neumair
 © 2002-2005 Christian Rose
 © 2014 Claudio Arseni
 © 2005-2007 Clytie Siddall
 © 2014 Daniel Korostil
 © 2011 Daniel Martinez Cucalon
 © 2014 Daniel Mustieles
 © 2007 Daniel Nylander
 © 2007 Danishka Navin
 © 2003 Deep_Dark
 © 2008 Denis Lackovic
 © 2014 Dimitris Spingos (Δημήτρης Σπίγγος)
 © 2003 Dinesh Nadarajah
 © 2007 Djavan Fagundes
 © 2006 Djihed Afifi
 © 2005 Donatien NSENGIYUMVA
 © 2007 Dr.T.Vasudevan
 © 2003-2007 Duarte Loreto
 © 2005 Elnaz Sarbar
 © 2014 Enrico Nicoletto
 © 2010 Erdal Ronahî
 © 2008 Erzhan Shaniev
 © 2002-2003 Evandro Fernandes Giovanini
 © 2008 F Wolff
 © 2003 FSF-India
 © 2010-2014 Fran Diéguez
 © 2003-2004 Francisco Javier F. Serrador
 © 2002-2010 Free Software Foundation, Inc.
 © 2003-2004 Funda Wang
 © 2003 G Karunakar
 © 2005-2008 Gabor Kelemen
 © 2004 Gareth Owen
 © 2010 Gheyret T.Kenji
 © 2014 Gil Forcada
 © 2002-2004 Gil Osher
 © 2007 Gintautas Miliauskas
 © 2006 Giulia
 © 2002-2012 Gnome Software Foundation
 © 2007 Gnome i18n Project for Vietnamese
 © 2011 GunChleoc
 © 2002 Hasbullah Bin Pit
 © 2003 He Qiangqiang
 © 2005-2007 Hendrik Richter
 © 2004-2007 Ignacion Casal Quinteiro
 © 2005 Igor Nestorović
 © 2002-2003 Igor Petreski
 © 2011 Ihar Hrachyshka
 © 2004-2005 Ivan Noris
 © 2005-2007 Ivar Smolin
 © 2003-2007 Iñaki Larrañaga Murgoitio
 © 2005 JEAN BAPTISTE NGENDAHAYO
 © 2002 Jeroen van der Vegt
 © 2002-2007 Jordi Mallach
 © 2012 Jorge Becerril
 © 2009 Jorge González
 © 2014 Juhani Numminen
 © 2003 KAMAGASAKO Masatoshi
 © 2004 Kemal Šanjta
 © 2006 Khaled Hosny
 © 2012 Khoem Sokhem
 © 2014 Kjartan Maraas
 © 2003-2012 Kostas Papadimas
 © 2010 Kristjan SCHMIDT
 © 2004 Laszlo Dvornik
 © 2003-2008 Laurent Dhima
 © 2010 Loba Yeasmeen
 © 2002-2007 Luca Ferretti
 © 2014 M.Hanny Sabbagh
 © 2004 MagNet
 © 2005 Mahay Alam Khan
 © 2009-2010 Manoj Kumar Giri
 © 2008 Marcel Telka
 © 2014 Marek Černocký
 © 2006 Maris ZInbergs
 © 2005 Martin Willemoes Hansen
 © 2007 Massimo Furlani
 © 2014 Matej Urbančič
 © 2003 Mathieu van Woerkom
 © 2009 Michael MORONI
 © 2014 Miroslav Nikolić
 © 2003-2004 Mișu Moldovan
 © 2005 Mohammad DAMT
 © 2008 Moldabekov Margulan
 © 2012 Morn Met
 © 2014 Muhammet Kara
 © 2003-2004 Mətin Əmirov
 © 2007 Nabin Gautam
 © 2007 Nguyễn Thái Ngọc Duy
 © 2012-2014 Nilamdyuti Goswami
 © 2009 Nils-Christoph Fiedler
 © 2005 Noëlla Mupole
 © 2009 Nurali Abdurahmonov
 © 2002-2004 Ole Laursen
 © 2002 Pablo Gonzalo del Campo
 © 2003 Pablo Saratxaga
 © 2004 Paisa Seeluangsawat
 © 2003 Paul Duffy
 © 2005 Philibert Ndandali
 © 2014 Piotr Drąg
 © 2008 Praveen|പ്രവീണ്‍ A|എ
 © 2003-2014 Prevod.org team
 © 2006 Rahul Bhalerao
 © 2009 Raivis Dejus
 © 2005-2009 Rajesh Ranjan
 © 2004-2005 Raphael Higino
 © 2004 Ravishankar Shrivastava
 © (unspecified) Renuka Prasad
 © 2009 Reşat SABIQ
 © 2008 Robert Sedak
 © 2003 Roozbeh Pournader
 © 2006-2011 Rosetta Contributors
 © 2004 Roy Chan
 © 2012 Rūdolfs Mazurs
 © 2005 Samia Niamatullah
 © 2004 Samúel Jón Gunnarsson
 © 2008 Sandeep Shedmake
 © 2009 Sangeeta Kumari
 © 2003 Sanlig Badral
 © 2008 Santhosh Thottingal
 © 2010 Sense Hofstede
 © 2008 Seán de Búrca
 © 2008 Shankar Prasad
 © 2003-2005 Sharif FarsiWeb, Inc.
 © 2003-2004 Stanislav Visnovsky
 © 2014 Stas Solovey
 © 2005 Steve Murphy
 © 2006 Subhransu Behera
 © 2007 Swecha Telugu Localisation Team
 © 2002 T.M.Thanh
 © 2010 Takayuki KUSANO
 © 2003-2007 Takeshi AIHANA
 © 2003 Taneem Ahmed
 © 2007 The GNOME Project
 © 2007 Theppitak Karoonboonyanan
 © 2006 Thierry Randrianiriana
 © 2009 Thomas Thurman
 © 2003 Tiago Cardoso Menezes
 © 2003-2004 Tino Meinen
 © 2003-2004 Tomas Kuliavas
 © 2007-2008 Tomasz Dominikowski
 © 2010 Torstein Adolf Winterseth
 © 2007 Tshewang Norbu
 © 2003 Tõivo Leedjärv
 © 2005 Viateur MUGENZI
 © 2013 Victor Ibragimov
 © 2005 Vijay Kiran Kamuju
 © 2006 Vladimer Sichinava
 © 2004 Vladimir Petkov
 © 2007 Wouter Bolsterlee
 © 2007 Y.Kiran Chandra
 © 2007 Yannig Marchegay (Kokoyaya)
 © 2014 Yosef Or Boczko
 © 2011 Yurek Hinz
 © 2008 Zabeeh Khan
 © 2003 Zbigniew Chyla
 © 2011 Zenat Rahnuma
 © 2010 argistitori
 © 2003 the GNOME team
 © 2003 www.gyfieithu.co.uk
 © 2004 Åsmund Skjæveland
 © 2004-2014 Žygimantas Beručka
License: CC-BY-SA-3.0-US or LGPL-3
 This work is licenced under the terms of either the GNU LGPL v3 or
 Creative Commons Attribution-Share Alike 3.0 United States License.
 .
 To view a copy of the CC-BY-SA licence, visit
 https://creativecommons.org/licenses/by-sa/3.0/ or send a letter to Creative
 Commons, 171 Second Street, Suite 300, San Francisco, California 94105, USA.
 .
 When attributing the artwork, using "GNOME Project" is enough.
 Please link to https://www.gnome.org where available.

Files:
 po/tk.po
Copyright:
 © 2004 Free Software Foundation
 © 2004 Gurban Mühemmet Tewekgeli and Kakilik - Turkmen free software developers community
License: GPL-unspecified
 This file is distributed under the terms of GNU General Public License (GPL)
Comment:
 On Debian systems, the complete text of the GNU General
 Public License can be found in `/usr/share/common-licenses/GPL'.

Files:
 Adwaita/scalable/status/night-light-symbolic.svg
 Adwaita/scalable/ui/pan-down-symbolic.svg
 Adwaita/scalable/ui/pan-end-symbolic-rtl.svg
 Adwaita/scalable/ui/pan-end-symbolic.svg
 Adwaita/scalable/ui/pan-start-symbolic-rtl.svg
 Adwaita/scalable/ui/pan-start-symbolic.svg
 Adwaita/scalable/ui/pan-up-symbolic.svg
 src/fullcolor/application-x-sharedlib.svg
 src/symbolic/gnome-stencils.svg
Copyright:
 unspecified, possibly © Jakub Steiner
License: CC-BY-SA-4.0

Files:
 src/fullcolor/accessories-dictionary.svg
Copyright:
 © Ulisse Perusin
 © Lapo Calamandrei
 © SoylentGreen
 © Luigi Chiesa
 © unknown contributor to FreeSeamlessTextures.com
License: GFDL-1.2+ or CC-BY-SA-3.0-Unported or CC-BY-SA-2.0-IT, and CC-BY-3.0-US

License: CC-BY-SA-3.0-Unported
 This file is licensed under the Creative Commons Attribution-Share
 Alike 3.0 Unported license.
 .
 You are free:
 .
 • to share – to copy, distribute and transmit the work
 • to remix – to adapt the work
 .
 Under the following conditions:
 • attribution – You must attribute the work in the manner specified
   by the author or licensor (but not in any way that suggests that they
   endorse you or your use of the work).
 • share alike – If you alter, transform, or build upon this work,
   you may distribute the resulting work only under the same or similar
   license to this one.
 .
EOF

open(LICENSE, 'debian/CC-BY-SA-3.0-Unported.license');
while(<LICENSE>) {
	s/^/ /;
	s/^ $/ ./;
	print;
}

print <<'EOF';

License: CC-BY-SA-4.0
 http://creativecommons.org/licenses/by-sa/4.0/
 .
EOF

open(LICENSE, 'debian/CC-BY-SA-4.0.license');
while(<LICENSE>) {
	s/^/ /;
	s/^ $/ ./;
	print;
}

print <<'EOF';

License: CC-BY-3.0-US
 <!-- Seamless texture provided by FreeSeamlessTextures.com -->
 <!-- License: creative commons attribution -->
 .
 From <http://freeseamlesstextures.com/>:
 .
 Are the textures on this site really free?
 .
 Yes. All the textures are free to download and use in both personal
 and commercial design projects. They are provided under a Creative
 Commons Attribution 3.0 License
 <https://creativecommons.org/licenses/by/3.0/us/>.
 Please credit this website when using our textures.
 .
EOF

open(LICENSE, 'debian/CC-BY-3.0-US.license');
while(<LICENSE>) {
	s/^/ /;
	s/^ $/ ./;
	print;
}

print <<'EOF';

License: CC-BY-SA-3.0-US
EOF

open(LICENSE, 'debian/CC-BY-SA-3.0-US.license');
while(<LICENSE>) {
	s/^/ /;
	s/^ $/ ./;
	print;
}

print <<'EOF';

License: CC-BY-SA-2.0-IT
 This file is licensed under the Creative Commons Attribution-Share
 Alike 2.0 Italy license.
 .
 You are free:
 .
 • to share – to copy, distribute and transmit the work
 • to remix – to adapt the work
 .
 Under the following conditions:
 .
 • attribution – You must attribute the work in the manner specified
   by the author or licensor (but not in any way that suggests that they
   endorse you or your use of the work).
 • share alike – If you alter, transform, or build upon this work,
   you may distribute the resulting work only under the same or similar
   license to this one.
 .
 ---- Full license text follows ----
 .
EOF

open(LICENSE, 'debian/CC-BY-SA-2.0-IT.license');
while(<LICENSE>) {
	s/^/ /;
	s/^ $/ ./;
	print;
}

print <<'EOF';

License: GFDL-1.2+
 Permission is granted to copy, distribute and/or modify this document
 under the terms of the GNU Free Documentation License, Version 1.2 or
 any later version published by the Free Software Foundation; with no
 Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts. A
 copy of the license is included in the section entitled GNU Free
 Documentation License.
Comment:
 On Debian systems, the complete text of the GFDL-1.2 can be found
 in /usr/share/common-licenses/GFDL-1.2.
EOF
